package com.example.pda.ui

import android.content.Context
import androidx.compose.foundation.clickable
import androidx.compose.runtime.*
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.platform.LocalConfiguration
import androidx.compose.ui.Modifier
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.itemsIndexed
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.ArrowBack
import androidx.compose.material.icons.filled.Check
import androidx.compose.material.icons.filled.Delete
import androidx.compose.material3.*
import androidx.compose.ui.Alignment
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.unit.dp
import android.media.AudioManager
import android.media.ToneGenerator
import com.example.pda.R
import com.example.pda.function.UBXScan

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun ScanScreen(
    onBack: () -> Unit,
    onResult: (String) -> Unit
) {
    val context = LocalContext.current
    val ubxScan = remember { UBXScan() }
    var isScanning by remember { mutableStateOf(true) }
    val scannedItems = remember { mutableStateListOf<String>() }
    var showConfirm by remember { mutableStateOf(false) }
    val configuration = LocalConfiguration.current
    val screenHeight = configuration.screenHeightDp.dp
    val boxHeight = screenHeight * 0.15f


    // 创建 ToneGenerator
    val toneGenerator = remember { ToneGenerator(AudioManager.STREAM_NOTIFICATION, 100) }

    DisposableEffect(Unit) {
        startScanning(context, ubxScan) { result ->
            // 添加扫描结果到列表
            if (isScanning) {
                scannedItems.add(result)
                showConfirm = true
                toneGenerator.startTone(ToneGenerator.TONE_PROP_BEEP)
            }
        }

        onDispose {
            stopScanning(ubxScan)
            isScanning = false
            toneGenerator.release()
        }
    }

    Scaffold(
        topBar = {
            TopAppBar(
                navigationIcon = {
                    IconButton(onClick = onBack) {
                        Icon(
                            imageVector = Icons.Default.ArrowBack,
                            contentDescription = "返回"
                        )
                    }
                },
                title = {
                    Row(verticalAlignment = Alignment.CenterVertically) {
                        Icon(
                            painter = painterResource(id = R.drawable.logo),
                            contentDescription = "PDA Logo",
                            modifier = Modifier.size(40.dp),
                            tint = MaterialTheme.colorScheme.surfaceTint
                        )
                        Spacer(Modifier.width(8.dp))
                        Text("信泰PDA—入库扫描")
                    }
                },
                colors = TopAppBarDefaults.topAppBarColors(
                    containerColor = Color(0xFFBCD0C5), // 自定义颜色
                    titleContentColor = MaterialTheme.colorScheme.onPrimary,
                    actionIconContentColor = MaterialTheme.colorScheme.onPrimary
                )
          
         
            )
        },
        floatingActionButton = {
            if (showConfirm) {
                ExtendedFloatingActionButton(
                    onClick = {
                        // 将列表转换为字符串传递（例如用逗号分隔）
                        onResult(scannedItems.joinToString(","))
                        scannedItems.clear()
                        showConfirm = false
                    },
                    icon = { Icon(Icons.Default.Check, "确认") },
                    text = { Text("确认提交") }
                )
            }
        }
    ) { innerPadding ->
        Column(
            modifier = Modifier
                .padding(innerPadding)
                .fillMaxSize()
        ) {
            // 扫描提示区域
            Box(
                modifier = Modifier
                    .height(boxHeight)
                    .fillMaxWidth()
                    .clickable(enabled = isScanning) { },
                contentAlignment = Alignment.Center
            ) {
            if (isScanning) {
                Column(
                    modifier = Modifier.fillMaxWidth(),
                     horizontalAlignment = Alignment.CenterHorizontally
                    ){
                     Text(text = "对准条码扫描")
                    }   
                }
            }

            // 已扫描列表
            LazyColumn(
                modifier = Modifier
                    .weight(1f)
                    .padding(8.dp)
            ) {
                itemsIndexed(scannedItems) { index, item ->
                    Row(
                        modifier = Modifier
                            .fillMaxWidth()
                            .padding(8.dp),
                        verticalAlignment = Alignment.CenterVertically
                    ) {
                        Text(
                            text = "${index + 1}. $item",
                            modifier = Modifier.weight(1f)
                        )
                        IconButton(
                            onClick = { scannedItems.removeAt(index) }
                        ) {
                            Icon(
                                imageVector = Icons.Default.Delete,
                                contentDescription = "删除"
                            )
                        }
                    }
                    Divider()
                }
            }
        }
    }
}

// 修改后的startScanning函数（不再直接调用onResult）
private fun startScanning(
    context: Context,
    ubxScan: UBXScan,
    onScanned: (String) -> Unit
) {
    
    ubxScan.setOnScanListener(context) { result ->
        onScanned(result)
    }
}
private fun stopScanning(ubxScan: UBXScan) {
    ubxScan.destroy()
}