package com.example.pda.ui.viewmodel

import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.example.pda.model.InventoryItem
import com.example.pda.network.NetworkHelper
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.StateFlow
import kotlinx.coroutines.launch

// ViewModel 类用于管理库存相关的UI状态和数据操作
class InventoryViewModel : ViewModel() {
    // 私有 MutableStateFlow 用于存储UI状态，初始状态为 Idle
    private val _uiState = MutableStateFlow<UiState>(UiState.Idle)
    // 公开的 StateFlow 提供给UI层观察当前UI状态
    val uiState: StateFlow<UiState> = _uiState

    // 密封类 UiState 用于表示不同的UI状态
    sealed class UiState {
        // 空闲状态
        object Idle : UiState()
        // 加载状态
        object Loading : UiState()
        // 成功状态，包含成功消息
        data class Success(val message: String) : UiState()
        // 错误状态，包含错误消息
        data class Error(val message: String) : UiState()
    }

    // 提交库存数据的方法
    fun submitData(data: List<InventoryItem>) {
        // 在 viewModelScope 中启动协程以提交数据
        viewModelScope.launch {
            // 设置UI状态为 Loading 表示正在加载
            _uiState.value = UiState.Loading
            // 调用 NetworkHelper 提交数据
            NetworkHelper.submitData(
                data = data,
                // 成功回调，设置UI状态为 Success 并包含成功消息
                onSuccess = {
                    _uiState.value = UiState.Success("提交成功")
                },
                // 错误回调，设置UI状态为 Error 并包含错误消息
                onError = { error ->
                    _uiState.value = UiState.Error(error)
                }
            )
        }
    }
   
   fun resetState() {
        // 重置 UI 状态
        _uiState.value = UiState.Idle
   }
    
}